import os
import logging
from flask import Flask, render_template, abort, jsonify, session, url_for, request, redirect
from datetime import datetime, timedelta
from pprint import pformat

from p2.ui.sessions import settings
from p2.store.client import Client
from p2.logging import HttpLogger

app = Flask(__name__)
app.config.from_object('p2.ui.schedule.settings')
app.secret_key = app.config['SECRET_KEY']

log = HttpLogger(
    level = logging.DEBUG,
    silent = False,
    name='p2.ui.resources'
)
logger = log.getLogger()


p2_store_url = os.getenv('P2_STORE_URL')
if p2_store_url is None:
    raise Exception("No P2_STORE_URL envar found")

client = Client(p2_store_url)

__version__='0.1.0'

@app.route('/version')
def version():
    return f"{__package__} version {__version__}"

@app.route('/menu')
def menu():
    return jsonify(settings.MENU)

@app.route('/api/display_sessions')
def display_sessions():
    sessions = client.select(
        table='exp_session_schedule',
        fetch=[
            'exp_id',
            'filepath',
            'start_time',
            'end_time',
            'mins',
            'hour',
            'dom',
            'month',
            'year',
            'context',
            'status',
            'target_name',
            'campaign_title',
            'duration'
        ])
    if sessions is None:
        raise Exception("Error: no sessions found")

    # determining start/end times for sessions
    # scheduled in the future...
    valid_sessions = list()
    for session in sessions:
        if (session['month'] is None) or \
            (session['dom']  is None) or \
            (session['hour'] is None) or \
            (session['mins'] is None):
                continue

        session['target_name'] = session['target_name'] or session['filepath']

        if session['start_time'] is None:
            start_time = datetime(
                year=session['year'],
                month=int(session['month']),
                day=int(session['dom']),
                hour=int(session['hour']),
                minute=int(session['mins']))
            session['start_time'] = start_time.isoformat()

            delta = timedelta(minutes=session['duration'])
            end_time = start_time + delta
            session['end_time'] = end_time.isoformat()

        valid_sessions.append(session)

    logger.debug("Sessions: {}".format(pformat(valid_sessions)))
    return jsonify(valid_sessions)
